========================
 Invenio-Records v0.3.3
========================

Invenio-Records v0.3.3 was released on September 14, 2015.

About
-----

Invenio-Records is a metadata storage module.

*This is an experimental developer preview release.*

Bug fixes
---------

- Adds missing `invenio_base` dependency.
- Removes dependency on JSONAlchemy from Invenio package.

Installation
------------

   $ pip install invenio-records==0.3.3

Documentation
-------------

   http://invenio-records.readthedocs.org/en/v0.3.3

Happy hacking and thanks for flying Invenio-Records.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-records
|   URL: http://invenio-software.org
